@@ -38,9 +38,11 @@ pb <- function(x, df = NULL, lambda = NULL, control=pb.control(...), ...)
 #-------------------------------------------------------------------------------
 #-------------------------------------------------------------------------------
 # the main function starts here
-         scall <- deparse(sys.call())
-            lx <- length(x)
+            scall <- deparse(sys.call())
+   no.dist.val <-  length(table(x))
+                lx <- length(x)
  control$inter <- if (lx<99) 10 else control$inter # this is to prevent singularities when length(x) is small:change to 99 30-11-11 MS
+ control$inter <- if (no.dist.val<=control$inter)  no.dist.val else control$inter 
             xl <- min(x)
             xr <- max(x)
           xmax <- xr + 0.01 * (xr - xl)
@@ -166,13 +168,13 @@ regpen <- function(y, X, w, lambda, D)# original
       GAIC   
     }
 # #-------------------------------------------------------------------------------
-# ## function to find the lambdas wich minimise the local GCV 
+# ## function to find the lambdas which minimise the local GCV 
       fnGCV <- function(lambda, k)
            {
     I.lambda.D <- (1+lambda*UDU$values)
            edf <- sum(1/I.lambda.D)
          y_Hy2 <- y.y-2*sum((yy^2)/I.lambda.D)+sum((yy^2)/((I.lambda.D)^2))
-           GCV <- (n*y_Hy2)/(n-k*edf)
+           GCV <- (n*y_Hy2)/(n-k*edf)^2
            GCV
            }  
 # #-------------------------------------------------------------------------------
